@@ -29,8 +29,9 @@
 
 #include <libedataserver/e-data-server-util.h>
 
-#include "camel-exchange-store.h"
 #include "camel-exchange-folder.h"
+#include "camel-exchange-settings.h"
+#include "camel-exchange-store.h"
 #include "camel-exchange-summary.h"
 #include "camel-exchange-utils.h"
 
@@ -41,16 +42,25 @@
 #define EXCHANGE_STOREINFO_VERSION 1
 
 /* Even if we are disconnected, we need to exchange_store_connect()
-   to get the offline data */
+ * to get the offline data */
 #define RETURN_VAL_IF_NOT_CONNECTED(store, cancellable, ex, val)\
-	if (!camel_exchange_store_connected (store, cancellable, ex) && \
+	if (!camel_exchange_store_connected (store, cancellable, NULL) && \
 	    !exchange_store_connect_sync (CAMEL_SERVICE (store), cancellable, ex)) \
 		return val;
 
 extern CamelServiceAuthType camel_exchange_password_authtype;
 extern CamelServiceAuthType camel_exchange_ntlm_authtype;
 
-G_DEFINE_TYPE (CamelExchangeStore, camel_exchange_store, CAMEL_TYPE_OFFLINE_STORE)
+/* Forward Declarations */
+static void camel_subscribable_init (CamelSubscribableInterface *interface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	CamelExchangeStore,
+	camel_exchange_store,
+	CAMEL_TYPE_OFFLINE_STORE,
+	G_IMPLEMENT_INTERFACE (
+		CAMEL_TYPE_SUBSCRIBABLE,
+		camel_subscribable_init))
 
 /* Note: steals @display_name. */
 static CamelFolderInfo *
@@ -76,16 +86,16 @@ make_folder_info (CamelExchangeStore *exch,
 	info->display_name = display_name;
 
 	/* Process the full-path and decode if required */
-	temp = strrchr (path+2, '/');
+	temp = strrchr (path + 2, '/');
 	if (temp) {
 		/* info->full_name should not have encoded path */
-		info->full_name = camel_url_decode_path (path+2);
+		info->full_name = camel_url_decode_path (path + 2);
 	} else {
 		/* If there are no sub-directories, decoded(name) will be
-		   equal to that of path+2.
-		   Ex: personal
+		 * equal to that of path+2.
+		 * Ex: personal
 		*/
-		info->full_name = g_strdup (path+2);
+		info->full_name = g_strdup (path + 2);
 	}
 	info->unread = unread_count;
 
@@ -401,34 +411,21 @@ exchange_store_can_refresh_folder (CamelStore *store,
                                    GError **error)
 {
 	CamelStoreClass *store_class;
-	CamelURL *url;
-	gboolean res;
+	CamelService *service;
+	CamelSettings *settings;
+	gboolean can_refresh;
+	gboolean check_all;
+
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	check_all = camel_exchange_settings_get_check_all (
+		CAMEL_EXCHANGE_SETTINGS (settings));
 
 	store_class = CAMEL_STORE_CLASS (camel_exchange_store_parent_class);
+	can_refresh = store_class->can_refresh_folder (store, info, error);
 
-	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
-
-	res = store_class->can_refresh_folder (store, info, error) ||
-	      (camel_url_get_param (url, "check_all") != NULL);
-
-	return res;
-}
-
-static gboolean
-exchange_store_folder_is_subscribed (CamelStore *store,
-                                     const gchar *folder_name)
-{
-	gboolean is_subscribed = FALSE;
-
-	d(printf ("is subscribed folder : %s\n", folder_name));
-	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
-		return FALSE;
-
-	if (!camel_exchange_utils_is_subscribed_folder (CAMEL_SERVICE (store), folder_name, &is_subscribed, NULL)) {
-		return FALSE;
-	}
-
-	return is_subscribed;
+	return can_refresh || check_all;
 }
 
 static CamelFolder *
@@ -729,12 +726,29 @@ exchange_store_rename_folder_sync (CamelStore *store,
 }
 
 static gboolean
-exchange_store_subscribe_folder_sync (CamelStore *store,
+exchange_store_folder_is_subscribed (CamelSubscribable *subscribable,
+                                     const gchar *folder_name)
+{
+	gboolean is_subscribed = FALSE;
+
+	d(printf ("is subscribed folder : %s\n", folder_name));
+	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (subscribable)))
+		return FALSE;
+
+	if (!camel_exchange_utils_is_subscribed_folder (CAMEL_SERVICE (subscribable), folder_name, &is_subscribed, NULL)) {
+		return FALSE;
+	}
+
+	return is_subscribed;
+}
+
+static gboolean
+exchange_store_subscribe_folder_sync (CamelSubscribable *subscribable,
                                       const gchar *folder_name,
                                       GCancellable *cancellable,
                                       GError **error)
 {
-	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
+	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (subscribable);
 
 	d(printf ("subscribe folder : %s\n", folder_name));
 	if (!camel_exchange_store_connected (exch, cancellable, NULL)) {
@@ -745,16 +759,16 @@ exchange_store_subscribe_folder_sync (CamelStore *store,
 	}
 
 	return camel_exchange_utils_subscribe_folder (
-		CAMEL_SERVICE (store), folder_name, error);
+		CAMEL_SERVICE (subscribable), folder_name, error);
 }
 
 static gboolean
-exchange_store_unsubscribe_folder_sync (CamelStore *store,
+exchange_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
                                         const gchar *folder_name,
                                         GCancellable *cancellable,
                                         GError **error)
 {
-	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
+	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (subscribable);
 
 	d(printf ("unsubscribe folder : %s\n", folder_name));
 	if (!camel_exchange_store_connected (exch, cancellable, NULL)) {
@@ -765,7 +779,7 @@ exchange_store_unsubscribe_folder_sync (CamelStore *store,
 	}
 
 	return camel_exchange_utils_unsubscribe_folder (
-		CAMEL_SERVICE (store), folder_name, error);
+		CAMEL_SERVICE (subscribable), folder_name, error);
 }
 
 static void
@@ -780,6 +794,7 @@ camel_exchange_store_class_init (CamelExchangeStoreClass *class)
 	object_class->constructed = exchange_store_constructed;
 
 	service_class = CAMEL_SERVICE_CLASS (class);
+	service_class->settings_type = CAMEL_TYPE_EXCHANGE_SETTINGS;
 	service_class->get_name = exchange_store_get_name;
 	service_class->connect_sync = exchange_store_connect_sync;
 	service_class->disconnect_sync = exchange_store_disconnect_sync;
@@ -787,7 +802,6 @@ camel_exchange_store_class_init (CamelExchangeStoreClass *class)
 
 	store_class = CAMEL_STORE_CLASS (class);
 	store_class->can_refresh_folder = exchange_store_can_refresh_folder;
-	store_class->folder_is_subscribed = exchange_store_folder_is_subscribed;
 	store_class->free_folder_info = camel_store_free_folder_info_full;
 	store_class->get_folder_sync = exchange_store_get_folder_sync;
 	store_class->get_folder_info_sync = exchange_store_get_folder_info_sync;
@@ -795,8 +809,14 @@ camel_exchange_store_class_init (CamelExchangeStoreClass *class)
 	store_class->create_folder_sync = exchange_store_create_folder_sync;
 	store_class->delete_folder_sync = exchange_store_delete_folder_sync;
 	store_class->rename_folder_sync = exchange_store_rename_folder_sync;
-	store_class->subscribe_folder_sync = exchange_store_subscribe_folder_sync;
-	store_class->unsubscribe_folder_sync = exchange_store_unsubscribe_folder_sync;
+}
+
+static void
+camel_subscribable_init (CamelSubscribableInterface *interface)
+{
+	interface->folder_is_subscribed = exchange_store_folder_is_subscribed;
+	interface->subscribe_folder_sync = exchange_store_subscribe_folder_sync;
+	interface->unsubscribe_folder_sync = exchange_store_unsubscribe_folder_sync;
 }
 
 static void
@@ -807,7 +827,6 @@ camel_exchange_store_init (CamelExchangeStore *exch)
 	exch->folders_lock = g_mutex_new ();
 	exch->folders = g_hash_table_new (g_str_hash, g_str_equal);
 
-	store->flags |= CAMEL_STORE_SUBSCRIPTIONS;
 	store->flags &= ~(CAMEL_STORE_VTRASH | CAMEL_STORE_VJUNK);
 	/* FIXME: Like the GroupWise provider, Exchange should also
 	have its own EXCAHNGE_JUNK flags so as to rightly handle
@@ -817,7 +836,7 @@ camel_exchange_store_init (CamelExchangeStore *exch)
 }
 
 /* Use this to ensure that the camel session is online and we are connected
-   too. Also returns the current status of the store */
+ * too. Also returns the current status of the store */
 gboolean
 camel_exchange_store_connected (CamelExchangeStore *store,
                                 GCancellable *cancellable,
@@ -843,7 +862,9 @@ camel_exchange_store_connected (CamelExchangeStore *store,
 }
 
 void
-camel_exchange_store_folder_created (CamelExchangeStore *estore, const gchar *name, const gchar *uri)
+camel_exchange_store_folder_created (CamelExchangeStore *estore,
+                                     const gchar *name,
+                                     const gchar *uri)
 {
 	CamelFolderInfo *info;
 
@@ -853,13 +874,15 @@ camel_exchange_store_folder_created (CamelExchangeStore *estore, const gchar *na
 	info = make_folder_info (estore, g_strdup (name), uri, -1, 0);
 	info->flags |= CAMEL_FOLDER_NOCHILDREN;
 
-	camel_store_folder_subscribed (CAMEL_STORE (estore), info);
+	camel_subscribable_folder_subscribed (CAMEL_SUBSCRIBABLE (estore), info);
 
 	camel_folder_info_free (info);
 }
 
 void
-camel_exchange_store_folder_deleted (CamelExchangeStore *estore, const gchar *name, const gchar *uri)
+camel_exchange_store_folder_deleted (CamelExchangeStore *estore,
+                                     const gchar *name,
+                                     const gchar *uri)
 {
 	CamelFolderInfo *info;
 	CamelFolder *folder;
@@ -877,7 +900,7 @@ camel_exchange_store_folder_deleted (CamelExchangeStore *estore, const gchar *na
 	}
 	g_mutex_unlock (estore->folders_lock);
 
-	camel_store_folder_unsubscribed (CAMEL_STORE (estore), info);
+	camel_subscribable_folder_unsubscribed (CAMEL_SUBSCRIBABLE (estore), info);
 
 	camel_folder_info_free (info);
 }
